@@ -108,7 +108,8 @@ class Account(base.Base):
 
     facebook_id = appier.field(
         index = "hashed",
-        safe = True
+        safe = True,
+        description = "Facebook ID"
     )
 
     twitter_username = appier.field(
@@ -118,12 +119,14 @@ class Account(base.Base):
 
     google_id = appier.field(
         index = "hashed",
-        safe = True
+        safe = True,
+        description = "Google ID"
     )
 
     live_id = appier.field(
         index = "hashed",
-        safe = True
+        safe = True,
+        description = "Live ID"
     )
 
     github_login = appier.field(
@@ -170,6 +173,15 @@ class Account(base.Base):
         meta = "datetime"
     )
 
+    avatar = appier.field(
+        type = appier.image(
+            width = 400,
+            height = 400,
+            format = "png"
+        ),
+        private = True
+    )
+
     roles = appier.field(
         type = appier.references(
             "Role",
@@ -484,6 +496,11 @@ class Account(base.Base):
         if send_email: account.email_new(password = password)
         return account
 
+    @classmethod
+    def _build(cls, model, map):
+        username = model["username"]
+        model["avatar_url"] = cls._get_avatar_url_g(username)
+
     @classmethod
     def _unset_session(cls, prefixes = None, safes = [], method = "delete"):
         prefixes = prefixes or cls.PREFIXES
@@ -509,6 +526,16 @@ class Account(base.Base):
             if not is_removable: continue
             delete(key)
 
+    @classmethod
+    def _get_avatar_url_g(cls, username, absolute = True, owner = None):
+        owner = owner or appier.get_app()
+        if not hasattr(owner, "admin_part"): return None
+        return owner.url_for(
+            "admin.avatar_account",
+            username = username,
+            absolute = absolute
+        )
+
     def pre_validate(self):
         base.Base.pre_validate(self)
         if hasattr(self, "username") and self.username:
@@ -527,6 +554,8 @@ class Account(base.Base):
         base.Base.pre_create(self)
         self.key = self.secret()
         self.confirmation_token = self.secret()
+        if not hasattr(self, "avatar") or not self.avatar:
+            self._set_avatar_d()
 
     def confirm_s(self, send_email = False):
         self.confirmation_token = None
@@ -604,6 +633,28 @@ class Account(base.Base):
         cls = self.__class__
         return cls.generate(value)
 
+    def _set_avatar_d(self, image = "avatar.png", mime = "image/png"):
+        if not hasattr(self.owner, "admin_part"): return
+        if not self.owner.admin_part: return
+        if not self.owner.admin_avatar_default: return
+
+        admin_part = self.owner.admin_part
+
+        file = open(admin_part.static_path + "/images/" + image, "rb")
+        try: data = file.read()
+        finally: file.close()
+
+        file_t = (image, mime, data)
+        self.avatar = appier.File(file_t)
+
+    def _get_avatar_url(self, absolute = True, owner = None):
+        cls = self.__class__
+        return cls._get_avatar_url_g(
+            self.username,
+            absolute = absolute,
+            owner = self.owner
+        )
+
     @property
     def email_f(self):
         if not self.email: return self.email
@@ -625,17 +676,16 @@ class Account(base.Base):
         self.save()
 
     @appier.operation(name = "Mark Unconfirmed")
-    def mark_unconfirmed_s(self, owner = None):
+    def mark_unconfirmed_s(self):
         self.enabled = False
         self.confirmation_token = self.secret()
         self.save()
 
     @appier.operation(name = "Email New")
-    def email_new(self, password = None, owner = None):
-        owner = owner or appier.get_app()
+    def email_new(self, password = None):
         account = self.reload(rules = False, meta = True)
         base.Base.send_email_g(
-            owner,
+            self.owner,
             "admin/email/account/new.html.tpl",
             receivers = [self.email_f],
             subject = "New account",
@@ -645,11 +695,10 @@ class Account(base.Base):
         )
 
     @appier.operation(name = "Email Confirm")
-    def email_confirm(self, owner = None):
-        owner = owner or appier.get_app()
+    def email_confirm(self):
         account = self.reload(rules = False, meta = True)
         base.Base.send_email_g(
-            owner,
+            self.owner,
             "admin/email/account/confirm.html.tpl",
             receivers = [self.email_f],
             subject = "Confirm account",
@@ -658,11 +707,10 @@ class Account(base.Base):
         )
 
     @appier.operation(name = "Email Recover")
-    def email_recover(self, owner = None):
-        owner = owner or appier.get_app()
+    def email_recover(self):
         account = self.reload(rules = False, meta = True)
         base.Base.send_email_g(
-            owner,
+            self.owner,
             "admin/email/account/recover.html.tpl",
             receivers = [self.email_f],
             subject = "Recover account",
@@ -670,6 +718,14 @@ class Account(base.Base):
             account = account
         )
 
+    @appier.link(name = "View Avatar", devel = True)
+    def view_avatar_url(self, absolute = False):
+        return appier.get_app().url_for(
+            "admin.avatar_account",
+            username = self.username,
+            absolute = absolute
+        )
+
     @property
     def confirmed(self):
         return self.enabled
