@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2016 Hive Solutions Lda.
+# Copyright (c) 2008-2017 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -44,45 +44,43 @@ from appier_extras.parts.admin.models import base
 class Settings(base.Base):
 
     facebook_token = appier.field(
-        index = True
+        index = "hashed"
     )
 
     github_token = appier.field(
-        index = True
+        index = "hashed"
     )
 
     google_token = appier.field(
-        index = True
+        index = "hashed"
     )
 
     google_refresh_token = appier.field(
-        index = True
+        index = "hashed"
     )
 
     google_email = appier.field(
-        index = True
+        index = "hashed"
     )
 
     google_scope = appier.field(
-        index = True,
         type = list
     )
 
     live_token = appier.field(
-        index = True
+        index = "hashed"
     )
 
     twitter_token = appier.field(
-        index = True
+        index = "hashed"
     )
 
     twitter_token_secret = appier.field(
-        index = True
+        index = "hashed"
     )
 
     extra = appier.field(
-        type = dict,
-        index = True
+        type = dict
     )
 
     @classmethod
