@@ -75,8 +75,8 @@ class AdminPart(
         appier.Part.__init__(self, *args, **kwargs)
         self.account_c = account_c
         self.layout = appier.conf("ADMIN_LAYOUT", "fluid")
-        self.theme = appier.conf("ADMIN_THEME", "modern")
-        self.style = appier.conf("ADMIN_STYLE", "romantic")
+        self.theme = appier.conf("ADMIN_THEME", "flat")
+        self.style = appier.conf("ADMIN_STYLE", "")
         self.libs = appier.conf("ADMIN_LIBS", "current")
 
     def load(self):
@@ -96,7 +96,6 @@ class AdminPart(
         self.owner.login_redirect = "admin.index"
         self.owner.logout_redirect = "admin.login"
         self.owner.admin_account = self.account_c
-        self.owner.admin_open = True
         self.owner.admin_login_redirect = "admin.index"
         self.owner.admin_logout_redirect = "admin.login"
         self.owner.admin_facebook_scope = ("email",)
@@ -104,6 +103,13 @@ class AdminPart(
         self.owner.admin_google_scope = ("email",)
         self.owner.admin_live_scope = ("wl.basic", "wl.emails")
 
+        self.owner.admin_open = appier.conf(
+            "ADMIN_OPEN", False, cast = bool
+        )
+        self.owner.admin_avatar_default = appier.conf(
+            "ADMIN_AVATAR_DEFAULT", False, cast = bool
+        )
+
         self.owner.lib_loaders["appier_extras"] = self._appier_extras_loader
         self.owner.lib_loaders["netius"] = self._netius_loader
         self.owner.lib_loaders["PIL"] = self._pil_loader
@@ -162,6 +168,7 @@ class AdminPart(
             (("POST",), "/admin/accounts", self.create_account),
             (("GET",), "/admin/accounts/<str:username>", self.show_account),
             (("GET",), "/admin/accounts/<str:username>/mail", self.mail_account),
+            (("GET",), "/admin/accounts/<str:username>/avatar", self.avatar_account),
             (("GET",), "/admin/models", self.list_models),
             (("GET",), "/admin/models/<str:model>.json", self.show_model_json, None, True),
             (("GET",), "/admin/models/<str:model>.csv", self.show_model_csv),
@@ -366,7 +373,7 @@ class AdminPart(
 
     def new_account(self):
         if not self.owner.admin_open: raise appier.SecurityError(
-            message = "signup not allowed"
+            message = "Signup not allowed"
         )
         return self.template(
             "account/new.html.tpl",
@@ -376,7 +383,7 @@ class AdminPart(
 
     def create_account(self):
         if not self.owner.admin_open: raise appier.SecurityError(
-            message = "signup not allowed"
+            message = "Signup not allowed"
         )
         account = self.account_c.new()
         account.type = self.account_c.USER_TYPE
@@ -385,6 +392,7 @@ class AdminPart(
         except appier.ValidationError as error:
             return self.template(
                 "account/new.html.tpl",
+                error = "Problems occurred creating account",
                 account = error.model,
                 errors = error.errors
             )
@@ -402,6 +410,30 @@ class AdminPart(
     def mail_account(self, username):
         raise appier.NotImplementedError()
 
+    def avatar_account(self, username):
+        strict = self.field("strict", False, cast = bool)
+        cache = self.field("cache", False, cast = bool)
+        account = self.account_c.get(
+            username = username,
+            rules = False
+        )
+        avatar = account.avatar if hasattr(account, "avatar") else None
+        if not avatar:
+            if strict: raise appier.NotFoundError(
+                message = "Avatar not found for user '%s'" % username,
+                code = 404
+            )
+            return self.send_static(
+                "images/avatar.png",
+                static_path = self.static_path
+            )
+        return self.send_file(
+            avatar.data,
+            content_type = avatar.mime,
+            etag = avatar.etag,
+            cache = cache
+        )
+
     @appier.ensure(token = "admin.options")
     def options(self):
         return self.template(
