@@ -62,7 +62,7 @@ class Live(object):
 
         if not account:
             if not create: raise appier.NotFoundError(
-                message = "no account found for live account"
+                message = "No account found for live account"
             )
 
             account = owner.admin_account(
